# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["ExecutionListParams"]


class ExecutionListParams(TypedDict, total=False):
    completed: Optional[bool]

    cron_id: Optional[str]

    cursor: Optional[str]

    from_: Annotated[Optional[int], PropertyInfo(alias="from")]

    limit: Optional[int]

    one_off_job_id: Optional[str]

    to: Optional[int]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .tenant import Tenant as Tenant
from .cron_job import CronJob as CronJob
from .execution import Execution as Execution
from .one_off_job import OneOffJob as OneOffJob
from .http_request import HTTPRequest as HTTPRequest
from .http_response import HTTPResponse as HTTPResponse
from .job_list_params import JobListParams as JobListParams
from .cron_list_params import CronListParams as CronListParams
from .job_create_params import JobCreateParams as JobCreateParams
from .job_list_response import JobListResponse as JobListResponse
from .job_update_params import JobUpdateParams as JobUpdateParams
from .cron_create_params import CronCreateParams as CronCreateParams
from .cron_list_response import CronListResponse as CronListResponse
from .cron_update_params import CronUpdateParams as CronUpdateParams
from .http_request_param import HTTPRequestParam as HTTPRequestParam
from .tenant_create_params import TenantCreateParams as TenantCreateParams
from .tenant_update_params import TenantUpdateParams as TenantUpdateParams
from .execution_list_params import ExecutionListParams as ExecutionListParams
from .execution_list_response import ExecutionListResponse as ExecutionListResponse
from .verify_retrieve_response import VerifyRetrieveResponse as VerifyRetrieveResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, Optional
from typing_extensions import Required, TypedDict

__all__ = ["HTTPRequestParam"]


class HTTPRequestParam(TypedDict, total=False):
    headers: Required[Dict[str, str]]

    method: Required[str]

    url: Required[str]

    body: Optional[str]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, Optional

from .._models import BaseModel

__all__ = ["HTTPRequest"]


class HTTPRequest(BaseModel):
    headers: Dict[str, str]

    method: str

    url: str

    body: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import TypedDict

__all__ = ["CronListParams"]


class CronListParams(TypedDict, total=False):
    cursor: Optional[str]

    limit: Optional[int]
